/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Copyright (C) 2017 Canonical Ltd
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QCONTACTCOLLECTIONCHANGESET_H
#define QCONTACTCOLLECTIONCHANGESET_H

#include <QtCore/qlist.h>
#include <QtCore/qset.h>
#include <QtCore/qshareddata.h>

#include <QtContacts/qcontactcollectionid.h>
#include <QtContacts/qcontactmanager.h>

QT_BEGIN_NAMESPACE_CONTACTS

class QContactManagerEngine;

class QContactCollectionChangeSetData;
class Q_CONTACTS_EXPORT QContactCollectionChangeSet
{
public:
    QContactCollectionChangeSet();
    QContactCollectionChangeSet(const QContactCollectionChangeSet &other);
    ~QContactCollectionChangeSet();

    QContactCollectionChangeSet &operator=(const QContactCollectionChangeSet &other);

    void setDataChanged(bool dataChanged);
    bool dataChanged() const;

    QSet<QContactCollectionId> addedCollections() const;
    void insertAddedCollection(const QContactCollectionId &collectionId);
    void insertAddedCollections(const QList<QContactCollectionId> &collectionIds);
    void clearAddedCollections();

    QSet<QContactCollectionId> changedCollections() const;
    void insertChangedCollection(const QContactCollectionId &collectionId);
    void insertChangedCollections(const QList<QContactCollectionId> &collectionIds);
    void clearChangedCollections();

    QSet<QContactCollectionId> removedCollections() const;
    void insertRemovedCollection(const QContactCollectionId &collectionId);
    void insertRemovedCollections(const QList<QContactCollectionId> &collectionIds);
    void clearRemovedCollections();

    QList<QPair<QContactCollectionId, QContactManager::Operation> > modifiedCollections() const;
    void clearModifiedCollections();

    void clearAll();

    void emitSignals(QContactManagerEngine *engine) const;

private:
    QSharedDataPointer<QContactCollectionChangeSetData> d;
};

QT_END_NAMESPACE_CONTACTS

#endif // QCONTACTCOLLECTIONCHANGESET_H
